@@ -14,31 +14,30 @@
  * limitations under the License.
  *
 */
-
-#ifdef _WIN32
-#pragma warning(push)
-#pragma warning(disable: 4005)
-#pragma warning(disable: 4251)
+#if defined(_MSC_VER)
+  #pragma warning(push)
+  #pragma warning(disable: 4005)
+  #pragma warning(disable: 4251)
 #endif
-#include <ignition/msgs/magnetometer.pb.h>
-#ifdef _WIN32
-#pragma warning(pop)
+#include <gz/msgs/magnetometer_sensor.pb.h>
+#if defined(_MSC_VER)
+  #pragma warning(pop)
 #endif
 
-#include <ignition/common/Profiler.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/transport/Node.hh>
 #include <sdf/Magnetometer.hh>
 
-#include "ignition/sensors/MagnetometerSensor.hh"
-#include "ignition/sensors/Noise.hh"
-#include "ignition/sensors/SensorFactory.hh"
-#include "ignition/sensors/SensorTypes.hh"
+#include "gz/sensors/MagnetometerSensor.hh"
+#include "gz/sensors/Noise.hh"
+#include "gz/sensors/SensorFactory.hh"
+#include "gz/sensors/SensorTypes.hh"
 
-using namespace ignition;
+using namespace gz;
 using namespace sensors;
 
 /// \brief Private data for MagnetometerSensor
-class ignition::sensors::MagnetometerSensorPrivate
+class gz::sensors::MagnetometerSensorPrivate
 {
   /// \brief node to create publisher
   public: transport::Node node;
