@@ -15,21 +15,21 @@
  *
 */
 
-#include "ignition/sensors/Manager.hh"
+#include "gz/sensors/Manager.hh"
 #include <memory>
 #include <unordered_map>
-#include <ignition/common/PluginLoader.hh>
-#include <ignition/common/Plugin.hh>
-#include <ignition/common/Profiler.hh>
-#include <ignition/common/SystemPaths.hh>
-#include <ignition/common/Console.hh>
+#include <gz/common/PluginLoader.hh>
+#include <gz/common/Plugin.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/common/SystemPaths.hh>
+#include <gz/common/Console.hh>
 
-#include "ignition/sensors/config.hh"
-#include "ignition/sensors/SensorFactory.hh"
+#include "gz/sensors/config.hh"
+#include "gz/sensors/SensorFactory.hh"
 
-using namespace ignition::sensors;
+using namespace gz::sensors;
 
-class ignition::sensors::ManagerPrivate
+class gz::sensors::ManagerPrivate
 {
   /// \brief constructor
   public: ManagerPrivate();
@@ -92,7 +92,7 @@ bool Manager::Remove(const SensorId _id)
 }
 
 //////////////////////////////////////////////////
-void Manager::RunOnce(const ignition::common::Time &_time, bool _force)
+void Manager::RunOnce(const gz::common::Time &_time, bool _force)
 {
   IGN_PROFILE("SensorManager::RunOnce");
   for (auto &s : this->dataPtr->sensors)
