@@ -17,9 +17,11 @@
 
 #include <gtest/gtest.h>
 
-#include <ignition/common/Filesystem.hh>
-#include <ignition/sensors/Manager.hh>
-#include <ignition/sensors/CameraSensor.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/common/Time.hh>
+#include <gz/sensors/Manager.hh>
+#include <gz/sensors/CameraSensor.hh>
+#include <gz/transport/Node.hh>
 
 // TODO(louise) Remove these pragmas once ign-rendering is disabling the
 // warnings
@@ -27,9 +29,9 @@
 #pragma warning(push)
 #pragma warning(disable: 4251)
 #endif
-#include <ignition/rendering/RenderEngine.hh>
-#include <ignition/rendering/RenderingIface.hh>
-#include <ignition/rendering/Scene.hh>
+#include <gz/rendering/RenderEngine.hh>
+#include <gz/rendering/RenderingIface.hh>
+#include <gz/rendering/Scene.hh>
 #ifdef _WIN32
 #pragma warning(pop)
 #endif
@@ -48,6 +50,20 @@
 #include "TransportTestTools.hh"
 
 
+std::mutex g_infoMutex;
+unsigned int g_infoCounter = 0;
+gz::msgs::CameraInfo g_infoMsg;
+
+//////////////////////////////////////////////////
+void OnCameraInfo(const gz::msgs::CameraInfo & _msg)
+{
+  g_infoMutex.lock();
+  g_infoCounter++;
+  g_infoMsg.CopyFrom(_msg);
+  g_infoMutex.unlock();
+}
+
+//////////////////////////////////////////////////
 class CameraSensorTest: public testing::Test,
   public testing::WithParamInterface<const char *>
 {
@@ -55,10 +71,11 @@ class CameraSensorTest: public testing::Test,
   public: void ImagesWithBuiltinSDF(const std::string &_renderEngine);
 };
 
+//////////////////////////////////////////////////
 void CameraSensorTest::ImagesWithBuiltinSDF(const std::string &_renderEngine)
 {
   // get the darn test data
-  std::string path = ignition::common::joinPaths(PROJECT_SOURCE_PATH, "test",
+  std::string path = gz::common::joinPaths(PROJECT_SOURCE_PATH, "test",
       "integration", "camera_sensor_builtin.sdf");
   sdf::SDFPtr doc(new sdf::SDF());
   sdf::init(doc);
@@ -72,7 +89,7 @@ void CameraSensorTest::ImagesWithBuiltinSDF(const std::string &_renderEngine)
   auto sensorPtr = linkPtr->GetElement("sensor");
 
   // Setup ign-rendering with an empty scene
-  auto *engine = ignition::rendering::engine(_renderEngine);
+  auto *engine = gz::rendering::engine(_renderEngine);
   if (!engine)
   {
     igndbg << "Engine '" << _renderEngine
@@ -80,13 +97,13 @@ void CameraSensorTest::ImagesWithBuiltinSDF(const std::string &_renderEngine)
     return;
   }
 
-  ignition::rendering::ScenePtr scene = engine->CreateScene("scene");
+  gz::rendering::ScenePtr scene = engine->CreateScene("scene");
 
   // do the test
-  ignition::sensors::Manager mgr;
+  gz::sensors::Manager mgr;
 
-  ignition::sensors::CameraSensor *sensor =
-      mgr.CreateSensor<ignition::sensors::CameraSensor>(sensorPtr);
+  gz::sensors::CameraSensor *sensor =
+      mgr.CreateSensor<gz::sensors::CameraSensor>(sensorPtr);
   ASSERT_NE(sensor, nullptr);
   sensor->SetScene(scene);
 
@@ -97,17 +114,74 @@ void CameraSensorTest::ImagesWithBuiltinSDF(const std::string &_renderEngine)
 
   EXPECT_EQ(std::string("base_camera"), sensor->FrameId());
 
+  // subscribe to the camera info topic
+  std::string infoTopic = sensor->InfoTopic();
+  gz::transport::Node node;
+  node.Subscribe(infoTopic, &OnCameraInfo);
+  WaitForMessageTestHelper<gz::msgs::CameraInfo> helperInfo(infoTopic);
+
   std::string topic = "/test/integration/CameraPlugin_imagesWithBuiltinSDF";
-  WaitForMessageTestHelper<ignition::msgs::Image> helper(topic);
+  WaitForMessageTestHelper<gz::msgs::Image> helper(topic);
 
   // Update once to create image
-  mgr.RunOnce(ignition::common::Time::Zero);
+  mgr.RunOnce(gz::common::Time::Zero);
 
   EXPECT_TRUE(helper.WaitForMessage()) << helper;
+  EXPECT_TRUE(helperInfo.WaitForMessage()) << helperInfo;
+
+  // Check CameraInfo properties
+  gz::msgs::CameraInfo infoMsg;
+  g_infoMutex.lock();
+  EXPECT_EQ(1u, g_infoCounter);
+  infoMsg.CopyFrom(g_infoMsg);
+  g_infoMutex.unlock();
+
+  {
+    auto intrinsics = infoMsg.intrinsics();
+    EXPECT_EQ(9, intrinsics.k_size());
+    EXPECT_DOUBLE_EQ(280.0, intrinsics.k(0));
+    EXPECT_DOUBLE_EQ(0.0, intrinsics.k(1));
+    EXPECT_DOUBLE_EQ(162.0, intrinsics.k(2));
+    EXPECT_DOUBLE_EQ(0.0, intrinsics.k(3));
+    EXPECT_DOUBLE_EQ(281.0, intrinsics.k(4));
+    EXPECT_DOUBLE_EQ(124.0, intrinsics.k(5));
+    EXPECT_DOUBLE_EQ(0.0, intrinsics.k(6));
+    EXPECT_DOUBLE_EQ(0.0, intrinsics.k(7));
+    EXPECT_DOUBLE_EQ(1.0, intrinsics.k(8));
+  }
+
+  {
+    auto projection = infoMsg.projection();
+    EXPECT_EQ(12, projection.p_size());
+    EXPECT_DOUBLE_EQ(282.0, projection.p(0));
+    EXPECT_DOUBLE_EQ(0.0, projection.p(1));
+    EXPECT_DOUBLE_EQ(163.0, projection.p(2));
+    EXPECT_DOUBLE_EQ(1.0, projection.p(3));
+    EXPECT_DOUBLE_EQ(0.0, projection.p(4));
+    EXPECT_DOUBLE_EQ(283.0, projection.p(5));
+    EXPECT_DOUBLE_EQ(125.0, projection.p(6));
+    EXPECT_DOUBLE_EQ(2.0, projection.p(7));
+    EXPECT_DOUBLE_EQ(0.0, projection.p(8));
+    EXPECT_DOUBLE_EQ(0.0, projection.p(9));
+    EXPECT_DOUBLE_EQ(1.0, projection.p(10));
+    EXPECT_DOUBLE_EQ(0.0, projection.p(11));
+  }
+
+  // test removing sensor
+  // first make sure the sensor objects do exist
+  auto sensorId = sensor->Id();
+  auto cameraId = sensor->RenderingCamera()->Id();
+  EXPECT_EQ(sensor, mgr.Sensor(sensorId));
+  EXPECT_EQ(sensor->RenderingCamera(), scene->SensorById(cameraId));
+  // remove and check sensor objects no longer exist in both sensors and
+  // rendering
+  EXPECT_TRUE(mgr.Remove(sensorId));
+  EXPECT_EQ(nullptr, mgr.Sensor(sensorId));
+  EXPECT_EQ(nullptr, scene->SensorById(cameraId));
 
   // Clean up
   engine->DestroyScene(scene);
-  ignition::rendering::unloadEngine(engine->Name());
+  gz::rendering::unloadEngine(engine->Name());
 }
 
 //////////////////////////////////////////////////
@@ -117,12 +191,12 @@ TEST_P(CameraSensorTest, ImagesWithBuiltinSDF)
 }
 
 INSTANTIATE_TEST_CASE_P(CameraSensor, CameraSensorTest,
-    RENDER_ENGINE_VALUES, ignition::rendering::PrintToStringParam());
+    RENDER_ENGINE_VALUES, gz::rendering::PrintToStringParam());
 
 //////////////////////////////////////////////////
 int main(int argc, char **argv)
 {
-  ignition::common::Console::SetVerbosity(4);
+  gz::common::Console::SetVerbosity(4);
   ::testing::InitGoogleTest(&argc, argv);
   return RUN_ALL_TESTS();
 }
