@@ -22,16 +22,16 @@
 #pragma warning(disable: 4005)
 #pragma warning(disable: 4251)
 #endif
-#include <ignition/msgs/camera_info.pb.h>
+#include <gz/msgs/camera_info.pb.h>
 #include <ignition/msgs.hh>
 #ifdef _WIN32
 #pragma warning(pop)
 #endif
 
-#include <ignition/common/Filesystem.hh>
-#include <ignition/common/Event.hh>
-#include <ignition/sensors/Manager.hh>
-#include <ignition/sensors/RgbdCameraSensor.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/common/Event.hh>
+#include <gz/sensors/Manager.hh>
+#include <gz/sensors/RgbdCameraSensor.hh>
 
 // TODO(louise) Remove these pragmas once ign-rendering is disabling the
 // warnings
@@ -39,11 +39,11 @@
 #pragma warning(push)
 #pragma warning(disable: 4251)
 #endif
-#include <ignition/rendering/Material.hh>
-#include <ignition/rendering/RenderEngine.hh>
-#include <ignition/rendering/RenderingIface.hh>
-#include <ignition/rendering/Scene.hh>
-#include <ignition/rendering/Visual.hh>
+#include <gz/rendering/Material.hh>
+#include <gz/rendering/RenderEngine.hh>
+#include <gz/rendering/RenderingIface.hh>
+#include <gz/rendering/Scene.hh>
+#include <gz/rendering/Visual.hh>
 #ifdef _WIN32
 #pragma warning(pop)
 #endif
@@ -56,7 +56,7 @@
 #define DEPTH_TOL 1e-4
 #define DOUBLE_TOL 1e-6
 
-using namespace ignition;
+using namespace gz;
 
 std::mutex g_mutex;
 unsigned int g_depthCounter = 0;
@@ -242,6 +242,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   box->SetLocalRotation(0, 0, 0);
   box->SetLocalScale(unitBoxSize, unitBoxSize, unitBoxSize);
   box->SetMaterial(blue);
+  scene->DestroyMaterial(blue);
   root->AddChild(box);
 
   // do the test
@@ -374,7 +375,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     EXPECT_EQ(0u, mr);
     EXPECT_EQ(0u, mg);
 #ifndef __APPLE__
-    // See https://github.com/ignitionrobotics/ign-sensors/issues/66
+    // See https://github.com/gazebosim/gz-sensors/issues/66
     EXPECT_GT(mb, 0u);
 #endif
 
@@ -440,7 +441,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     EXPECT_EQ(0u, mr);
     EXPECT_EQ(0u, mg);
 #ifndef __APPLE__
-    // See https://github.com/ignitionrobotics/ign-sensors/issues/66
+    // See https://github.com/gazebosim/gz-sensors/issues/66
     EXPECT_GT(mb, 0u);
 #endif
 
@@ -526,11 +527,9 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   g_imgMutex.unlock();
 
   // Check that for a box really close it returns -inf
-  root->RemoveChild(box);
   math::Vector3d boxPositionNear(
       unitBoxSize * 0.5 + near_ * 0.5, 0.0, 0.0);
   box->SetLocalPosition(boxPositionNear);
-  root->AddChild(box);
 
   mgr.RunOnce(common::Time::Zero, true);
   for (int sleep = 0; sleep < 300 &&
@@ -632,11 +631,9 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   g_pcMutex.unlock();
 
   // Check that for a box really far it returns inf
-  root->RemoveChild(box);
   math::Vector3d boxPositionFar(
       unitBoxSize * 0.5 + far_ * 1.5, 0.0, 0.0);
   box->SetLocalPosition(boxPositionFar);
-  root->AddChild(box);
 
   mgr.RunOnce(common::Time::Zero, true);
   for (int sleep = 0; sleep < 300 &&
@@ -737,7 +734,12 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   g_imgMutex.unlock();
   g_pcMutex.unlock();
 
+  // Clean up rendering ptrs
+  box.reset();
+  blue.reset();
+
   // Clean up
+  mgr.Remove(rgbdSensor->Id());
   engine->DestroyScene(scene);
   rendering::unloadEngine(engine->Name());
 }
